/* @(#)89       1.6 src/ivauthn/modules/pdxauthn/pdxauthn/xnvlist.h, pdweb.authn, amweb410, 020709a 7/7/02 17:29:20 */
/*
 * xnvlist.h
 *
 * List of name-value pairs.
 */

#ifndef XNVLIST_H
#define XNVLIST_H

#if defined(__cplusplus)
extern "C" {
#endif

typedef struct {
    char *name; 
    char *value;
    int  vlen;
} xnvlist_item_t;

typedef struct {
    long            length; /* number of items in list */
    xnvlist_item_t   *items; /* array of list elements. */
} xnvlist_t;

#include <ogauthzn.h>
#include <pdxauthn_decl.h>


/*
 * Allocates an xnvlist_t and returns it.  Returns NULL on allocation
 * failure.
 */
PDXUTILS_DECLSPEC
xnvlist_t*
PDXUTILS_CALLTYPE
xnvlist_malloc(int list_size);

/*
 * Frees an xnvlist_t and any items in the list.
 */
PDXUTILS_DECLSPEC
void
PDXUTILS_CALLTYPE
xnvlist_free(xnvlist_t *list);

/*
 * Return a pointer pointing to the value of 
 * the specified name in the xnvlist.
 */
PDXUTILS_DECLSPEC
int
PDXUTILS_CALLTYPE
xnvlist_get(xnvlist_t *list, char *name, char **value, int *vlen);

/*
 * Return a pointer pointing to the value of 
 * the specified name the xnvlist.
 */
PDXUTILS_DECLSPEC
int
PDXUTILS_CALLTYPE
xnvlist_lookup(xnvlist_t *list, char *name, char **value, int *vlen);

/*
 * Return a pointer pointing to the value of 
 * the specified name the xnvlist.
 */
PDXUTILS_DECLSPEC
int
PDXUTILS_CALLTYPE
xnvlist_caselookup(xnvlist_t *list, char *name, char **value, int *vlen);

/*
 * Set the name/value pair to the xnvlist 
 */
PDXUTILS_DECLSPEC
int 
PDXUTILS_CALLTYPE
xnvlist_set(xnvlist_t *list, char *name, char *value, int vlen);

/*
 * Duplicate the xnvlist.
 */
PDXUTILS_DECLSPEC
xnvlist_t *
PDXUTILS_CALLTYPE
xnvlist_dup(xnvlist_t *list);

/*
 * Duplicate the items in the nvlist.
 */
PDXUTILS_DECLSPEC
xnvlist_item_t *
PDXUTILS_CALLTYPE
xnvlist_items_dup(xnvlist_t *list);

/*
 * Convert a credential encoded as a value into a credential.  The credential
 * should NOT be released later.
 */
PDXUTILS_DECLSPEC
azn_creds_h_t
PDXUTILS_CALLTYPE
xauthn_util_entry_to_creds(const char *value, int vlen);

#if defined(__cplusplus)
}
#endif

#endif /* end XNVLIST_H */
